/* ====================================================================
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
==================================================================== */

package org.apache.poi.xwpf.usermodel;

import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Calendar;

import junit.framework.TestCase;

import org.apache.poi.xwpf.XWPFTestDataSamples;

public final class TestXWPFComments extends TestCase {
    
    public void testAddComment() throws IOException {
        XWPFDocument docOut = new XWPFDocument();

        XWPFComment xComment = docOut.addNewComment();
        xComment.setAuthor("Author");
        xComment.setId(0);
        xComment.setInitials("AUT");
        Calendar calendar = Calendar.getInstance();
        xComment.setDate(calendar);
        
        XWPFParagraph p1 = docOut.createParagraph();
        XWPFRun r1 = p1.createRun();
        r1.setText("This is sample text with a ");
        p1.createCommentRangeStart(xComment);
        XWPFRun r2 = p1.createRun();
        r2.setText("comment");
        p1.createCommentRangeEnd(xComment);
        XWPFRun r3 = p1.createRun();
        r3.setText(" included.");
        p1.createCommentReference(xComment);
 
        XWPFParagraph p = xComment.createParagraph();
        XWPFRun r = p.createRun();
        r.setText("This is comment content.");
        
        XWPFDocument docIn = XWPFTestDataSamples.writeOutAndReadBack(docOut);
        
        assertEquals(1, docIn.getComments().length);
        assertEquals("Author", docIn.getCommentByID(0).getAuthor());
        assertEquals("AUT", docIn.getCommentByID(0).getInitials());
        assertEquals(calendar.getTimeInMillis(), docIn.getCommentByID(0).getDate().getTimeInMillis());
        assertEquals("This is comment content.", docIn.getCommentByID(0).getText());
        assertEquals("This is comment content.", docIn.getCommentByID(0).getParagraphs().get(0).getRuns().get(0).getText(0));
        
        assertEquals(1, docIn.getParagraphs().get(0).getCTP().sizeOfCommentRangeStartArray());
        assertEquals(1, docIn.getParagraphs().get(0).getCTP().sizeOfCommentRangeEndArray());
 
    }
}
